==> dde-launchpad_0.0.2.tar.xz: BUILD/translations/dde-launchpad_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="27"/>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="37"/>
        <source>Pin to Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="43"/>
        <source>Remove from favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="43"/>
        <source>Add to favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="57"/>
        <source>Send to desktop</source>
        <translation>Kiinnitä työpöydälle</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="57"/>
        <source>Remove from desktop</source>
        <translation>Poista työpöydältä</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="67"/>
        <source>Send to dock</source>
        <translation>Kiinnitä telakkaan</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="67"/>
        <source>Remove from dock</source>
        <translation>Poista telakasta</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="78"/>
        <source>Add to startup</source>
        <translation>Lisää käynnistykseen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="78"/>
        <source>Remove from startup</source>
        <translation>Poista käynnistyksestä</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="83"/>
        <source>Use a proxy</source>
        <translation>Käytä välityspalvelinta</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="86"/>
        <source>Uninstall</source>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>AppListView</name>
    <message>
        <location filename="../qml/AppListView.qml" line="34"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../qml/AppListView.qml" line="36"/>
        <source>Chat</source>
        <translation>Chatti</translation>
    </message>
    <message>
        <location filename="../qml/AppListView.qml" line="38"/>
        <source>Music</source>
        <translation>Musiikki</translation>
    </message>
    <message>
        <location filename="../qml/AppListView.qml" line="40"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../qml/AppListView.qml" line="42"/>
        <source>Graphics</source>
        <translation>Grafiikka</translation>
    </message>
    <message>
        <location filename="../qml/AppListView.qml" line="44"/>
        <source>Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppListView.qml" line="46"/>
        <source>Office</source>
        <translation>Toimisto</translation>
    </message>
    <message>
        <location filename="../qml/AppListView.qml" line="48"/>
        <source>Reading</source>
        <translation>Lukeminen</translation>
    </message>
    <message>
        <location filename="../qml/AppListView.qml" line="50"/>
        <source>Development</source>
        <translation>Ohjelmointi</translation>
    </message>
    <message>
        <location filename="../qml/AppListView.qml" line="52"/>
        <source>System</source>
        <translation>Järjestelmä</translation>
    </message>
    <message>
        <location filename="../qml/AppListView.qml" line="54"/>
        <source>Others</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <source>Search</source>
        <translation type="obsolete">Etsi</translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="202"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="210"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="218"/>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="41"/>
        <source>Categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="117"/>
        <source>Power</source>
        <translation>Virta</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="130"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="73"/>
        <location filename="../qml/WindowedFrame.qml" line="154"/>
        <source>Search</source>
        <translation>Etsi</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="172"/>
        <source>My Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="203"/>
        <source>Add your favorite apps here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="213"/>
        <source>All Apps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="186"/>
        <location filename="../qml/WindowedFrame.qml" line="237"/>
        <source>No search results</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> dde-launchpad_0.4.4.tar.xz: BUILD/translations/dde-launchpad_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="27"/>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="37"/>
        <source>Pin to Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="46"/>
        <source>Remove from favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="46"/>
        <source>Add to favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="60"/>
        <source>Send to desktop</source>
        <translation>Kiinnitä työpöydälle</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="60"/>
        <source>Remove from desktop</source>
        <translation>Poista työpöydältä</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="70"/>
        <source>Send to dock</source>
        <translation>Kiinnitä telakkaan</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="70"/>
        <source>Remove from dock</source>
        <translation>Poista telakasta</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="81"/>
        <source>Add to startup</source>
        <translation>Lisää käynnistykseen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="81"/>
        <source>Remove from startup</source>
        <translation>Poista käynnistyksestä</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="86"/>
        <source>Use a proxy</source>
        <translation>Käytä välityspalvelinta</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="89"/>
        <source>Uninstall</source>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>AppListView</name>
    <message>
        <source>Internet</source>
        <translation type="vanished">Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="vanished">Chatti</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">Musiikki</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="vanished">Grafiikka</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="vanished">Toimisto</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="vanished">Lukeminen</translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="vanished">Ohjelmointi</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="vanished">Järjestelmä</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <source>Search</source>
        <translation type="obsolete">Etsi</translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="18"/>
        <source>Internet</source>
        <translation type="unfinished">Internet</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="20"/>
        <source>Chat</source>
        <translation type="unfinished">Chatti</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="22"/>
        <source>Music</source>
        <translation type="unfinished">Musiikki</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="24"/>
        <source>Video</source>
        <translation type="unfinished">Video</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="26"/>
        <source>Graphics</source>
        <translation type="unfinished">Grafiikka</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="28"/>
        <source>Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="30"/>
        <source>Office</source>
        <translation type="unfinished">Toimisto</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="32"/>
        <source>Reading</source>
        <translation type="unfinished">Lukeminen</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="34"/>
        <source>Development</source>
        <translation type="unfinished">Ohjelmointi</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="36"/>
        <source>System</source>
        <translation type="unfinished">Järjestelmä</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="38"/>
        <source>Others</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="250"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="258"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="266"/>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="105"/>
        <source>Power</source>
        <translation>Virta</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">Asetukset</translation>
    </message>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="338"/>
        <location filename="../qml/WindowedFrame.qml" line="260"/>
        <source>Search</source>
        <translation>Etsi</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="117"/>
        <source>Control Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="159"/>
        <source>My Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="189"/>
        <source>Add your favorite apps here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="200"/>
        <source>All Apps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="323"/>
        <location filename="../qml/WindowedFrame.qml" line="224"/>
        <source>No search results</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
